@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 18:45:55 1995
  * Project:     INN (innfeed)
  * File:        article.c
- * RCSId:       $Id: article.c,v 1.12 1996/04/13 02:51:33 brister Exp $
+ * RCSId:       $Id: article.c,v 1.14 1996/05/23 21:16:04 brister Exp $
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
  *              Permission to use, copy, modify, and distribute this
@@ -37,7 +37,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: article.c,v 1.12 1996/04/13 02:51:33 brister Exp $" ;
+static const char *rcsid = "$Id: article.c,v 1.14 1996/05/23 21:16:04 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -623,9 +623,12 @@ static bool fillContents (Article article)
           if ((amt = read (fd, buffer + idx,amtToRead)) <= 0)
             {
               syslog (LOG_ERR,BAD_ART_READ, article->fname) ;
+              bytesInUse -= buf.st_size ;
+              byteTotal -= buf.st_size ;
+              amtToRead = 0 ;
+
               delBuffer (article->contents) ;
               article->contents = NULL ;
-              amtToRead = 0 ;
             }
           else
             {
@@ -672,7 +675,11 @@ static bool fillContents (Article article)
               else
                 {
                   syslog (LOG_ERR,PREPARE_FAILED) ;
+                  bytesInUse -= buf.st_size ;
+                  byteTotal -= buf.st_size ;
+
                   delBuffer (article->contents) ;
+                  article->contents = NULL ;
                 }
             }
         }
@@ -720,7 +727,10 @@ static bool prepareArticleForNNTP (Article article)
   if (contents == NULL)
     return false ;
   else if (article->nntpBuffers != NULL)
-    return true ;               /* already done */
+    {
+      delBuffer (contents) ;
+      return true ;               /* already done */
+    }
 
   if (dotBuffer == NULL)
     {
@@ -843,7 +853,7 @@ static Article hashFindArticle (const char *msgid)
     if (strcmp (msgid,h->article->msgid) == 0)
       break ;
 
-  return (h == NULL ? NULL : artTakeRef (h->article)) ;
+  return (h == NULL ? NULL : h->article) ;
 }
 
 
@@ -929,7 +939,7 @@ static void hashValidateTable (void)
   int i ;
   HashEntry he ;
 
-#ifndef NDEBUG
+#if ! defined (NDEBUG)
   for (i = 0 ; i < TABLE_SIZE ; i++)
     for (he = hashTable [i] ; he != NULL ; he = he->next)
       ASSERT (he->article->refCount > 0) ;
