@@ -4,7 +4,7 @@
  * Start Date:  Mon, 15 Jan 1996 17:31:58 +1100
  * Project:     INN -- innfeed
  * File:        main.c
- * RCSId:       $Id: main.c,v 1.11 1996/04/13 03:01:57 brister Exp $
+ * RCSId:       $Id: main.c,v 1.13 1996/05/23 21:23:53 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: main.c,v 1.11 1996/04/13 03:01:57 brister Exp $" ;
+static const char *rcsid = "$Id: main.c,v 1.13 1996/05/23 21:23:53 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -77,9 +77,6 @@ static void use_rcsid (const char *rid) {   /* Never called */
 #include "endpoint.h"
 #include "host.h"
 #include "innlistener.h"
-#if defined (USE_COMMANDERS)
-#include "commander.h"
-#endif
 
 
 extern int debugWrites ;
@@ -133,16 +130,9 @@ int main (int argc, char **argv)
   bool immedOpen, seenV = false ;
   u_short portNum ;
   bool dynamicPeers = false ;
-  time_t now = time (NULL) ;
+  time_t now = theTime() ;
   char dateString [30] ;
 
-#if defined (USE_COMMANDERS)
-  char *commanderAfUnix ;
-  Commander unixCommander, inetCommander ;
-  int cmdrFd, commanderPort = COMMANDER_PORT ;
-  struct sockaddr_in cmdrInAddr ;
-#endif
-
   strcpy (dateString,ctime(&now)) ;
   dateString [24] = '\0' ;
 
@@ -151,22 +141,10 @@ int main (int argc, char **argv)
   else
     program++ ;
 
-#if defined (USE_COMMANDERS)
-  /* set up the name of the AF_UNIX socket we'll listen to for command
-     connections. */
-  commanderAfUnix = MALLOC (strlen (COMMANDER_SOCKET) + 1) ; 
-  ASSERT (commanderAfUnix != NULL) ;
-  strcpy (commanderAfUnix,COMMANDER_SOCKET) ;
-#endif
-
   gPrintInfo = gprintinfo ;
 
 
-#if defined (USE_COMMANDERS)
-#define OPT_STRING "zymvhxb:l:c:a:d:s:p:"
-#else
 #define OPT_STRING "zymvhxb:l:c:d:s:"
-#endif
   
   while ((optVal = getopt (argc,argv,OPT_STRING)) != EOF)
     {
@@ -180,22 +158,6 @@ int main (int argc, char **argv)
             hostLogConnectionStats (true) ;
             break ;
             
-#if defined (USE_COMMANDERS)
-          case 'p':
-            if ((commanderPort = atoi (optarg)) == 0)
-              die ("invalid argument 'p': %s", optarg) ;
-            break ;
-
-          case 'a':
-            FREE (commanderAfUnix) ;
-            commanderAfUnix = optarg ;
-            if (strlen (optarg) == 0)
-              commanderAfUnix = NULL ;
-            else
-              commanderAfUnix = optarg ;
-            break ;
-#endif
-
           case 'x':
             talkToSelf = true ;
             break ;
@@ -268,8 +230,6 @@ int main (int argc, char **argv)
         die ("fopen (%s): %s", LOG_FILE, strerror (errno)) ;
     }
 
-  
-  
 #if defined (DO_HAVE_SETBUFFER)
   setbuffer (stdout, NULL, 0) ;
   setbuffer (stderr, NULL, 0) ;
@@ -284,7 +244,7 @@ int main (int argc, char **argv)
       exit (0) ;
     }
 
-  openlog (program,OPENLOG_FLAGS,LOG_NEWS) ;
+  openlog (program,L_OPENLOG_FLAGS,LOG_NEWS) ;
   syslog (LOG_NOTICE,STARTING_PROGRAM,versionInfo,dateString) ;
 
   openfds = 4 ;                 /* stdin, stdout, stderr and syslog */
@@ -371,7 +331,7 @@ int main (int argc, char **argv)
 
       if (fstat (0,&buf) < 0)
         {
-          syslog (LOG_ERR,FSTAT_FAILURE,0) ;
+          syslog (LOG_ERR,FSTAT_FAILURE,"stdin") ;
           exit (1) ;
         }
       else if (S_ISREG (buf.st_mode))
@@ -392,69 +352,8 @@ int main (int argc, char **argv)
     }
 
 
-#if defined (USE_COMMANDERS)
-  
-    /*
-     * setup the sockets for the commanders to listen on
-     */
-
-#if defined (DO_HAVE_UNIX_DOMAIN)
-
-  if (commanderAfUnix != NULL)
-    {
-      struct sockaddr_un cmdrUnAddr ;
-    
-      if ((strlen (commanderAfUnix) + 1)> sizeof (cmdrUnAddr.sun_path))
-        die ("pathname too long: %s\n", commanderAfUnix) ;
-
-      unlink (commanderAfUnix) ;
-    
-      if ((cmdrFd = socket (AF_UNIX, SOCK_STREAM, 0)) < 0)
-        die ("socket: %s",strerror (errno)) ;
-
-      openfds++ ;
-
-      memset (&cmdrUnAddr, 0, sizeof (cmdrUnAddr)) ;
-      cmdrUnAddr.sun_family = AF_UNIX ;
-      strcpy (cmdrUnAddr.sun_path, commanderAfUnix) ;
-      if (bind (cmdrFd, (struct sockaddr *) &cmdrUnAddr,
-                AF_UNIX_SOCKSIZE (cmdrUnAddr)) != 0)
-        die ("bind: %s", strerror (errno)) ;
-    
-      if (listen (cmdrFd, 5) != 0)
-        die ("listen: %s", strerror (errno)) ;
-    
-      unixCommander = newCommander (cmdrFd) ;
-  }
-
-#endif  /* defined(DO_HAVE_UNIX_DOMAIN) */
-
-
-  if (commanderPort > 0)
-    {
-      if ((cmdrFd = socket (AF_INET, SOCK_STREAM, 0)) < 0)
-        die ("socket: %s",strerror (errno)) ;
-      
-      openfds++ ;
-
-      memset (&cmdrInAddr, 0, sizeof (cmdrInAddr)) ;
-      cmdrInAddr.sin_family = AF_INET ;
-      cmdrInAddr.sin_port = htons (commanderPort) ;
-      
-      if (bind (cmdrFd, (struct sockaddr *) &cmdrInAddr,
-                sizeof (cmdrInAddr)) != 0)
-        die ("bind: %s", strerror (errno)) ;
-
-      if (listen (cmdrFd,5) != 0)
-        die ("listen: %s",strerror (errno)) ;
-
-      inetCommander = newCommander (cmdrFd) ;
-    }
-#endif
-  
     /* hook up the endpoint to the source of new article information (usually
        innd). */
-  
   ep = newEndPoint (0) ;        /* fd 0, i.e. stdin */
 
     /* now arrange for this endpoint to always be the first one checked for
@@ -810,14 +709,14 @@ static void sigchld (int sig)
 {
   int pid ;
 #if defined (DO_USE_UNION_WAIT)
-  int status ;
-#else
   union wait status ;
+#else
+  int status ;
 #endif
 
   (void) sig ;                  /* keep lint happy */
   
-#if DO_HAVE_WAITPID
+#if defined (DO_HAVE_WAITPID)
   pid = waitpid (-1, &status, WNOHANG);
 #else
   pid = wait3 (&status, WNOHANG, (struct rusage *) NULL);
@@ -842,9 +741,13 @@ static void sigusr (int sig)
 static void gprintinfo (void)
 {
   FILE *fp = fopen (SNAPSHOT_FILE,"a") ;
-  time_t now = time (NULL) ;
+  time_t now = theTime() ;
 
-  ASSERT (fp != NULL) ;
+  if (fp == NULL)
+    {
+      syslog (LOG_ERR,NO_SNAPSHOT,SNAPSHOT_FILE) ;
+      return ;
+    }
 
 #if defined (DO_HAVE_SETBUFFER)
   setbuffer (fp, NULL, 0) ;
