@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 17:10:18 1995
  * Project:     INN (innfeed)
  * File:        misc.c
- * RCSId:       $Id: misc.c,v 1.8 1996/04/13 02:51:33 brister Exp $
+ * RCSId:       $Id: misc.c,v 1.10 1996/05/23 21:27:32 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: misc.c,v 1.8 1996/04/13 02:51:33 brister Exp $" ;
+static const char *rcsid = "$Id: misc.c,v 1.10 1996/05/23 21:27:32 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -71,6 +71,7 @@ static void use_rcsid (const char *rid) {   /* Never called */
 
 #include "misc.h"
 #include "msgs.h"
+#include "endpoint.h"
 
 
 u_int openfds ;
@@ -154,7 +155,7 @@ void dprintf (u_int level, const char *fmt, ...)
   if (loggingLevel < level)
     return ;
   
-  now = time (NULL) ;
+  now = theTime() ;
   strcpy (timeString, ctime (&now) + 4) ; /* strip off leading day name */
   timeString [15] = '\0' ;      /* strip off trailing year and newline */
 
@@ -171,20 +172,31 @@ void (*gCleanUp) (void) = 0 ;
 
 void die (const char *fmt, ...)
 {
+  char timeString [30] ;
+  time_t now = time (NULL) ;
   va_list ap ;
 
+  strcpy (timeString,ctime (&now)) ;
+  timeString [24] = '\0' ;
+  
   va_start (ap, fmt) ;
-  fprintf (stderr, "%s: ", (program ? program : "UNKNOWN PROGRAM NAME")) ;
+  fprintf (stderr, "%s %s: ",
+           timeString, (program ? program : "UNKNOWN PROGRAM NAME")) ;
   vfprintf (stderr, fmt, ap) ;
   fprintf (stderr,"\n") ;
   va_end (ap) ;
 
+#if SNAPSHOT_ON_DIE
   if (debuggingDump && gPrintInfo != NULL)
     gPrintInfo () ;
+#endif
 
   if (gCleanUp != NULL)
     gCleanUp () ;
   
+  if (CORE_DIRECTORY != NULL)
+    (void) chdir (CORE_DIRECTORY) ;
+  
   abort () ;
 }
 
@@ -316,7 +328,7 @@ writev(fd, vp, vpcount)
 
 
 
-#if defined (NEED_STRDUP)
+#if defined (DO_NEED_STRDUP)
 
 char *strdup (const char *string)
 {
@@ -449,6 +461,7 @@ void trim_ws (char *string)
 }
 
 
+#if 0
 /* Scribble on top of memory we're about to free. */
 void deadBeef (void *base, size_t byteCount)
 {
@@ -492,7 +505,7 @@ void deadBeef (void *base, size_t byteCount)
 
 #endif
 }
-
+#endif 
 
 /* Not using plain flock or lockf 'cause I don't want to waste file
    descriptors. This routine is based on the file shlock.c from INN. */
@@ -520,6 +533,7 @@ bool lockFile (const char *fileName)
       switch (errno)
         {
           default:
+            unlink (tmpName) ;
             syslog (LOG_ERR,NO_OPEN_LOCK,tmpName) ;
             return false ;
 
@@ -613,7 +627,7 @@ void unlockFile (const char *lockfile)
 
 
 
-#if NEED_STRERROR
+#if defined (DO_NEED_STRERROR)
 
 extern int sys_nerr;
 extern char *sys_errlist[];
@@ -622,14 +636,14 @@ char *strerror (int errnum)
 {
     static char buff[30];
 
-    if (e >= 0 && e < sys_nerr)
-      return sys_errlist[e];
+    if (errnum >= 0 && errnum < sys_nerr)
+      return sys_errlist[errnum];
 
-    (void)sprintf(buff, "Error code %d\n", e);
+    (void)sprintf(buff, "Error code %d\n", errnum);
     return buff;
 }
 
-#endif /* NEED_STRERROR */
+#endif /* defined (NEED_STRERROR) */
 
 
 
@@ -703,12 +717,6 @@ bool isOlder (const char *file1, const char *file2)
 
 void freeCharP (char *charp)
 {
-#ifdef DEADBEEF
-  size_t len = strlen (charp) + 1 ;
-  
-  deadBeef (charp,len) ;
-#endif
-
   FREE (charp) ;
 }
 
